#!/bin/bash
#
# Part of Darius Tools
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
# see http://sv.nongnu.org/projects/darius-tools
# comments to <darius-tools-dev@nongnu.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#    USA
#
# $Id: ogg2wav.sh,v 1.1 2003/01/10 00:51:41 yeupou Exp $

########################################
# Configuration preset

# Usual for Darius Tools bash scripts
DARIUS_AUTHOR="2001-2003 Mathieu Roy"
DARIUS_MAIL="darius-tools-dev@nongnu.org"

DARIUS_NAME="ogg2wav"
DARIUS_VER="1.0"
DARIUS_DESC="Convert each ogg [or mp3] files in a dir to wav."
DARIUS_USAGE="[OPTION]"
DARIUS_REQUIRE="df, ogg123, [mpg321]"
DARIUS_HELP_00="  -s, --strict               only convert files with a correct suffix"
DARIUS_HELP_01="                             (.ogg, .mp3)"
DARIUS_HELP_02="      --ogg PATH             ogg files directory's path (default pwd)"
DARIUS_HELP_03="      --wav PATH             wav files directory's path (default pwd/wav)"
DARIUS_HELP_04="      --mp3                  files are mp3, not ogg"
DARIUS_HELP_05="      --mp3-info             show info about mp3 and exit"
DARIUS_HELP_06="  -f, --force                doesn't prompt the user to acknowledge options"         
DARIUS_HELP_07="WARNING: all files in the specified directory will be converted"
# Specific
TYPE=ogg
NAME_POLICY=nevermind
OGG=`pwd`
WAV=$OGG/wav
unset FORCE

########################################
# Functions definition

# Usual for Darius Tools bash scripts
# Previously, it was in a pseudo-library. But finally I prefer to avoid
# too much dependancies. 
function DARIUS_help {
        echo "Usage : $DARIUS_NAME $DARIUS_USAGE"
	echo "$DARIUS_DESC"
	echo ""
        echo "  -h, --help                 display this help and exit"
        echo "      --version              output version information and exit"
	if [ "$DARIUS_HELP_00" ]; then echo "$DARIUS_HELP_00" ; fi
	if [ "$DARIUS_HELP_01" ]; then echo "$DARIUS_HELP_01" ; fi
	if [ "$DARIUS_HELP_02" ]; then echo "$DARIUS_HELP_02" ; fi
	if [ "$DARIUS_HELP_03" ]; then echo "$DARIUS_HELP_03" ; fi
	if [ "$DARIUS_HELP_04" ]; then echo "$DARIUS_HELP_04" ; fi
	if [ "$DARIUS_HELP_05" ]; then echo "$DARIUS_HELP_05" ; fi
	if [ "$DARIUS_HELP_06" ]; then echo "$DARIUS_HELP_06" ; fi
	if [ "$DARIUS_HELP_07" ]; then echo "$DARIUS_HELP_07" ; fi
	if [ "$DARIUS_HELP_08" ]; then echo "$DARIUS_HELP_08" ; fi
	if [ "$DARIUS_HELP_09" ]; then echo "$DARIUS_HELP_09" ; fi
	if [ "$DARIUS_HELP_10" ]; then echo "$DARIUS_HELP_10" ; fi
	if [ "$DARIUS_HELP_11" ]; then echo "$DARIUS_HELP_11" ; fi
	if [ "$DARIUS_HELP_12" ]; then echo "$DARIUS_HELP_12" ; fi
	if [ "$DARIUS_HELP_13" ]; then echo "$DARIUS_HELP_13" ; fi
	if [ "$DARIUS_HELP_14" ]; then echo "$DARIUS_HELP_14" ; fi
	if [ "$DARIUS_HELP_15" ]; then echo "$DARIUS_HELP_15" ; fi
	echo ""
	if [ "$DARIUS_REQUIRE" ]; then echo "To use this script, you need $DARIUS_REQUIRE" ; fi
	echo "Report bugs or suggestions to <$DARIUS_MAIL>"
	exit
}

function DARIUS_version {
    echo "$DARIUS_NAME (Darius Tools) $DARIUS_VER"
    echo ""
    echo "Copyright (c) $DARIUS_AUTHOR <$DARIUS_MAIL>"
    echo "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
    exit
}

# Specific
function DARIUS_oggwav_show_option {
    echo "Configuration for this session:"
    echo "  checking file name policy... $NAME_POLICY"
    echo "  checking input file type... $TYPE"
    echo "  $TYPE files should be in $OGG"
    echo "  wav files will be written in $WAV"
    echo " "
    if [ ! $FORCE ] ; then
	echo "If that's ok, type enter (otherwise, type CTRL-C)"
	read void
    fi
}

function DARIUS_oggwav_mp3_infos {
    if [ "$TYPE" == "mp3" ] ; then
	echo " "
	echo -e "\\033[1;31m""Are you aware that mp3 is not really *free* ?""\\033[0;39m"
	echo "You should take a look at :"
	echo "  http://www.mp3licensing.com"
	echo "  http://www.mp3licensing.com/royalty"
	echo "  http://www.transnationale.org/fiches/-1686450519.htm (french)"
        echo " "
	sleep 3s
    fi
}

function DARIUS_oggwav_convert {
    cd "$OGG"
    if [ ! -e "$WAV" ] ; then
	mkdir -pv "$WAV"
    fi
    if [ $NAME_POLICY == "strict" ] ; then
	in=*.$TYPE
    else
	in=*
    fi
    for file in $in ; do
	df
	if [ "$TYPE" == "ogg" ] ; then
	    ogg123 -v -d wav -f "$WAV/$file.wav" "$file"
	elif [ "$TYPE" == "mp3" ] ; then
	    mpg321 --wav "$WAV/$file.wav" "$file"
	else 
	    echo "$DARIUS_NAME: unable to identify file type"
	    exit
	fi
    done
}
    
########################################
# Here we go

# Get options
GETOPT_TEMP=`getopt -o hvsf --long help,version,strict,ogg:,wav:,mp3,mp3-info,force \
     -n $DARIUS_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# Set action
while true ; do
    case "$1" in
	-h|--help) DARIUS_help ; break ;;
	--version) DARIUS_version ; break ;;
	--mp3-info) TYPE=mp3 && DARIUS_oggwav_mp3_infos && exit ; break ;;
	-s|--strict) NAME_POLICY=strict ; shift ;;
	--mp3) TYPE=mp3 ; shift ;;
	--ogg) OGG="$2" ; shift 2 ;;
	--wav) WAV="$2" ; shift 2 ;;
	-f|--force) FORCE=1 ; break ;;
	*) break ;;
    esac
done

DARIUS_oggwav_show_option
DARIUS_oggwav_mp3_infos
DARIUS_oggwav_convert

# End
########################################