#!/bin/bash
#
# Part of Darius Tools
# (c) 2001-2002 Mathieu Roy <yeupou@gnu.org>
#
# see http://sv.nongnu.org/projects/darius-tools
# comments to <darius-tools-dev@nongnu.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#    USA
#
# $Id: wav2ogg.sh,v 1.1 2003/01/10 00:51:41 yeupou Exp $

########################################
# Configuration preset

# Usual for Darius Tools bash scripts
DARIUS_AUTHOR="2001-2003 Mathieu Roy"
DARIUS_MAIL="darius-tools-dev@nongnu.org"

DARIUS_NAME="wav2ogg"
DARIUS_VER="1.0"
DARIUS_DESC="Convert each wav files in a dir to ogg."
DARIUS_USAGE="[OPTION] --band band_name"
DARIUS_REQUIRE="df, oggenc, urlize, tr"
DARIUS_HELP_00="  -s, --strict               only convert files with a correct suffix"
DARIUS_HELP_01="                             (.wav)"
DARIUS_HELP_02="      --ogg PATH             ogg files directory's path (default pwd/ogg)"
DARIUS_HELP_03="      --wav PATH             wav files directory's path (default pwd)"
DARIUS_HELP_04="      --band band_name       band name (required)"
DARIUS_HELP_05="      --album album_name     album name"
DARIUS_HELP_06="      --comment comment      encoding comment"
DARIUS_HELP_07="  -r, --remove               remove wav files once converted"
DARIUS_HELP_08="  -f, --force                doesn't prompt the user to acknowledge options"
DARIUS_HELP_09=" "
DARIUS_HELP_10="WARNING: all files in the specified directory will be converted"
DARIUS_HELP_11="         file names will be interpreted as songs name"

# Specific
TYPE=ogg
NAME_POLICY=nevermind
REMOVE=nothing
WAV=`pwd`
OGG=$WAV/ogg
unset FORCE


########################################
# Functions definition

# Usual for Darius Tools bash scripts
# Previously, it was in a pseudo-library. But finally I prefer to avoid
# too much dependancies. 
function DARIUS_help {
        echo "Usage : $DARIUS_NAME $DARIUS_USAGE"
	echo "$DARIUS_DESC"
	echo ""
        echo "  -h, --help                 display this help and exit"
        echo "      --version              output version information and exit"
	if [ "$DARIUS_HELP_00" ]; then echo "$DARIUS_HELP_00" ; fi
	if [ "$DARIUS_HELP_01" ]; then echo "$DARIUS_HELP_01" ; fi
	if [ "$DARIUS_HELP_02" ]; then echo "$DARIUS_HELP_02" ; fi
	if [ "$DARIUS_HELP_03" ]; then echo "$DARIUS_HELP_03" ; fi
	if [ "$DARIUS_HELP_04" ]; then echo "$DARIUS_HELP_04" ; fi
	if [ "$DARIUS_HELP_05" ]; then echo "$DARIUS_HELP_05" ; fi
	if [ "$DARIUS_HELP_06" ]; then echo "$DARIUS_HELP_06" ; fi
	if [ "$DARIUS_HELP_07" ]; then echo "$DARIUS_HELP_07" ; fi
	if [ "$DARIUS_HELP_08" ]; then echo "$DARIUS_HELP_08" ; fi
	if [ "$DARIUS_HELP_09" ]; then echo "$DARIUS_HELP_09" ; fi
	if [ "$DARIUS_HELP_10" ]; then echo "$DARIUS_HELP_10" ; fi
	if [ "$DARIUS_HELP_11" ]; then echo "$DARIUS_HELP_11" ; fi
	if [ "$DARIUS_HELP_12" ]; then echo "$DARIUS_HELP_12" ; fi
	if [ "$DARIUS_HELP_13" ]; then echo "$DARIUS_HELP_13" ; fi
	if [ "$DARIUS_HELP_14" ]; then echo "$DARIUS_HELP_14" ; fi
	if [ "$DARIUS_HELP_15" ]; then echo "$DARIUS_HELP_15" ; fi
	echo ""
	if [ "$DARIUS_REQUIRE" ]; then echo "To use this script, you need $DARIUS_REQUIRE" ; fi
	echo "Report bugs or suggestions to <$DARIUS_MAIL>"
	exit
}

function DARIUS_version {
    echo "$DARIUS_NAME (Darius Tools) $DARIUS_VER"
    echo ""
    echo "Copyright (c) $DARIUS_AUTHOR <$DARIUS_MAIL>"
    echo "This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
    exit
}

# Specific
function DARIUS_wavogg_show_option {
    echo "Configuration for this session:"
    echo "  checking file name policy... $NAME_POLICY"
    echo "  checking what should be done of $TYPE after the conversion... $REMOVE"
    echo "  $TYPE files should be in $OGG"
    echo "  wav files will be written in $WAV"
    echo "  band name is $BAND"
    echo "  album name is $ALBUM"
    echo "  comment content is $COMMENT"
    echo " "
    if [ ! $FORCE ] ; then
	echo "If that's ok, type enter (otherwise, type CTRL-C)"
	read void
    fi
}

function DARIUS_wavogg_convert {
    cd "$WAV"
    if [ ! -e "$OGG" ] ; then
	mkdir -pv "$OGG"
    fi
    if [ $NAME_POLICY == "strict" ] ; then
	in=*.$TYPE
    else
	in=*
    fi
    for file in $in ; do
	df
	FILENAME=`echo "$BAND" | tr a-z A-Z`"-$file.$TYPE"
	FILENAME=`urlize -e "$FILENAME"`
	if [ "$ALBUM" ] ; then
	    ENC_OPTION="--album $ALBUM"
	fi
	if [ "$COMMENT" ] ; then
	    ENC_OPTION="$ENC_OPTION --comment=$COMMENT"
	fi
	oggenc --output="$OGG/$FILENAME" --artist "$BAND" --title "$file" $ENC_OPTION "$file"
	if [ $REMOVE == trash ] ; then
	    rm -f "$file"
	fi
    done
}
    


########################################
# Here we go

# Get options
GETOPT_TEMP=`getopt -o hvsfr --long help,version,strict,ogg:,wav:,force,remove,band:,comment:,album: \
     -n $DARIUS_NAME -- "$@"`

eval set -- "$GETOPT_TEMP"

# Set action
while true ; do
    case "$1" in
	-h|--help) DARIUS_help ; break ;;
	--version) DARIUS_version ; break ;;
	-s|--strict) NAME_POLICY=strict ; shift ;;
	-r|--remove) REMOVE=trash ; shift ;;
	-f|--force) FORCE=1 ; shift ;;
	--ogg) OGG="$2" ; shift 2 ;;
	--wav) WAV="$2" ; shift 2 ;;
	--band) BAND="$2" ; shift 2 ;;
	--album) ALBUM="$2" ; shift 2 ;;
	--comment) COMMENT="$2" ; break ;;
	*) break ;;
    esac
done

if [ ! $BAND ] ; then    
    echo "$DARIUS_NAME: no band name specified"
    exit
fi

DARIUS_wavogg_show_option
DARIUS_wavogg_convert

# End
########################################